#!/ussr/bin/env python

import sys
import textwrap

import argparse



'''fold [ -bs ] [-w width | -width] [file]
-b	Count width in bytes rather than column positions.
-s	If a segment of a line contains a blank character within the first

width column positions (or bytes), break the line after the last such
blank character meeting the width constraints. If there is no blank
character meeting the requirements, the -s option will have no effect
for that output segment of the input line.

-w width | -width	Specify the maximum line length, in column positions

(or bytes if -b is specified). If width is not a positive decimal

number, an error is returned. The default value is 80.

file	A path name of a text file to be folded. If no file operands are
specified, the standard input will be used.'''


def main():
    parser = argparse.ArgumentParser(prog='fold.py', description=__doc__)

    parser.add_argument('FILE', type=file, nargs='*', default=[sys.stdin])
    parser.add_argument('-b', '--bytes', action='store_true',
                        help='count bytes rather than columns')
    parser.add_argument('-s', '--space', action='store_true')
    parser.add_argument('-w', '--width', type=int, default=80)

    args = parser.parse_args()
    
    fold(args.FILE[0])

def fold(in_file):
    out_file = sys.stdout

    out_line = ''

    for in_line in in_file:
        line = in_line.strip()

        if len(line) < 2:
            out_line = textwrap.fill(out_line)
            out_file.write(out_line)
            out_file.write('\n\n')
            out_line = ''

        else:
            out_line = ' '.join([out_line, in_line]).strip()

    in_file.close()
    out_line = textwrap.fill(out_line)
    out_file.write(out_line)
    out_file.close()

if __name__ == '__main__':
    main()
