#!/usr/bin/env python
'''list directory contents'''

import os
import sys

import argparse

class HelpAction(argparse.Action):
    def __call__(self, parser, namespace, values, option_string=None):
        parser.print_help()

parser = argparse.ArgumentParser(description=__doc__,
                                 add_help=False)
                                 
parser.add_argument('FILE', type=file, nargs='*', default=sys.stdin)
parser.add_argument('-a', '--all', action='store_true',
                    help='do not ignore entries starting with .')

parser.add_argument('-A', '--almost-all', action='store_true',
                    help='do not list implied . and ..')

parser.add_argument('--author', action='store_true',
                    help='with -l, print the author of each file')

parser.add_argument('-b', '--escape', action='store_true',
                    help='print octal escapes for nongraphic characters')

parser.add_argument('--block-size', metavar='SIZE', type=int,
                    help='use SIZE-byte blocks')

parser.add_argument('-B', '--ignore-backups', action='store_true',
                    help='do not list implied entries ending with ~')

parser.add_argument('-c', action='store_true',
                    help='with -lt: sort by, and show, ctime '
                         '(time of last modification of '
                         'file status information) '
                         'with -l: show ctime and  sort  by  name'
                         'otherwise: sort by ctime')

parser.add_argument('-C', action='store_true',
                    help='list entries by columns')

parser.add_argument('--color', metavar='WHEN', 
                    choices=('never', 'always', 'auto'),
                    help='control  whether  color is used to distinguish '
                         "file types.  WHEN "
                         "may be `never', `always', or `auto'")

parser.add_argument('-d', '--directory', action='store_true',
                    help='list directory entries instead of contents, and '
                         'do not  dereference symbolic links')

parser.add_argument('-D', '--dired', action='store_true',
                    help="generate output designed for Emacs' dired mode")

parser.add_argument('-f', action='store_true',
                    help='do not sort, enable -aU, disable -ls --color')

parser.add_argument('-F', '--classify', action='store_true',
                    help='append indicator (one of */=>@|) to entries')

parser.add_argument('--file-type', action='store_true',
                    help="likewise, except do not append `*'")

parser.add_argument('--format', metavar='WORD',
                    help='across  -x, commas -m, horizontal -x, '
                         'long -l, single-column -1, '
                         'verbose -l, vertical -C')

parser.add_argument('--full-time', action='store_true',
                    help='like -l --time-style=full-iso')

parser.add_argument('-g', action='store_true',
                    help='like -l, but do not list owner')

parser.add_argument('--group-directories-first',  action='store_true',
                    help='group directories before files. '
                         'augment with a --sort option, but any use  of  '
                         '--sort=none  (-U) disables grouping')

parser.add_argument('-G', '--no-group', action='store_true',
                    help="in a long listing, don't print group names")

parser.add_argument('-h', '--human-readable', action='store_true',
                    help='with -l, print sizes in human readable format '
                         '(e.g., 1K 234M 2G)')

parser.add_argument('--si', action='store_true',
                    help='likewise, but use powers of 1000 not 1024')
                    
parser.add_argument('-H', '--dereference-command-line', action='store_true',
                    help='follow symbolic links listed on the command line')

parser.add_argument('--dereference-command-line-symlink-to-dir', 
                    action='store_true',
                    help='follow  each  command line symbolic link that '
                         'points to a directory')

parser.add_argument('--hide', metavar='PATTERN',
                    help='do not list implied entries matching shell PATTERN '
                         '(overridden by -a or -A)')

parser.add_argument('--indicator-style', metavar='WORD',
                    help='append indicator with style WORD to entry names: '
                         'none (default), slash (-p), file-type '
                         '(--file-type), classify (-F)')

parser.add_argument('-i', '--inode', action='store_true',
                    help='print the index number of each file')

parser.add_argument('-I', '--ignore', metavar='PATTERN',
                    help='do not list implied entries matching shell PATTERN')

parser.add_argument('-k',  
                    dest='block_size', action='store_const', const='1K',
                    help='like --block-size=1K')

parser.add_argument('-l', action='store_true', 
                    help='use a long listing format')

parser.add_argument('-L', '--dereference', action='store_true',
                    help='when showing file information for a symbolic link, ' 
                         'show information  for  the file the link '
                         'references rather than for the link itself')

parser.add_argument('-m', action='store_true',
                    help='fill width with a comma separated list of entries')

parser.add_argument('-n', '--numeric-uid-gid', action='store_true',
                    help='like -l, but list numeric user and group IDs')
                    
parser.add_argument('-N', '--literal', action='store_true',
                    help="print raw entry names (don't treat e.g. control "
                         "characters  specially)")

parser.add_argument('-o', action='store_true',
                    help='like -l, but do not list group information')

parser.add_argument('-p', '--indicator-style=slash', action='store_true',
                    help='append / indicator to directories')

parser.add_argument('-q', '--hide-control-chars', action='store_true',
                    help='print ? instead of non graphic characters')

parser.add_argument('--show-control-chars', action='store_true',
                    help="show  non  graphic  characters  as-is "
                         "(default unless program is `ls' and output is a "
                         "terminal)")

parser.add_argument('-Q', '--quote-name', action='store_true',
                    help='enclose entry names in double quotes')

parser.add_argument('--quoting-style', metavar='WORD',
                    choices=('literal', 'locale',  'shell', 'shell-always', 
                             'c', 'escape'),
                    help='use quoting style WORD for entry names: literal, '
                         'locale,  shell, shell-always, c, escape')

parser.add_argument('-r', '--reverse', action='store_true',
                    help='reverse order while sorting')

parser.add_argument('-R', '--recursive', action='store_true',
                    help='list subdirectories recursively')

parser.add_argument('-s', '--size', action='store_true',
                    help='print the allocated size of each file, in blocks')

parser.add_argument('-S',  action='store_true',
                    help='sort by file size')

parser.add_argument('--sort', metavar='WORD',
                    help='sort  by  WORD  instead of name: '
                         'none -U, extension -X, size -S, time -t, '
                         'version -v')
parser.add_argument('--time', metavar='WORD',
                    help='with -l, show time as WORD instead of modification '
                         'time:  atime -u,  access  -u,  use  -u, ctime -c, '
                         'or status -c; use specified time as sort key if '
                         '--sort=time')

parser.add_argument('--time-style', metavar='STYLE',
                    help='with -l, show times using style STYLE: full-iso, '
                         'long-iso,  iso, locale,  +FORMAT.\n'
                         "FORMAT is interpreted like `date'; if FORMAT "
                         'is FORMAT1<newline>FORMAT2, FORMAT1 applies to '
                         'non-recent  files and FORMAT2 to recent files; '
                         "if STYLE is prefixed with `posix-', "
                         'STYLE takes effect only outside the POSIX locale')

parser.add_argument('-t', action='store_true',
                    help='sort by modification time')

parser.add_argument('-T', '--tabsize', metavar='COLS', default=8,
                    help='assume tab stops at each COLS instead of 8')

parser.add_argument('-u', action='store_true',
                    help='with -lt: sort by, and show, access time with  -l: '
                         'show  access time and sort by name otherwise: '
                         'sort by access time')

parser.add_argument('-U', action='store_true',
                    help='do not sort; list entries in directory order')

parser.add_argument('-v', action='store_true',
                    help='natural sort of (version) numbers within text')

parser.add_argument('-w', '--width', metavar='COLS',
                    help='assume screen width instead of current value')

parser.add_argument('-x',  action='store_true',
                    help='list entries by lines instead of by columns')

parser.add_argument('-X', action='store_true',
                    help='sort alphabetically by entry extension')

parser.add_argument('-Z', '--context', action='store_true',
                    help='print any SELinux security context of each file')

parser.add_argument('-1', action='store_true',
                    help='list one file per line')

parser.add_argument('--help', nargs=0, action=HelpAction,
                    help='output help text and exit')

parser.add_argument('--version',
                    help='output version information and exit')

args = parser.parse_args()
