#!/usr/bin/env python
'''Sleep for a period of time'''

import os
import sys
import time

import argparse

def sleep(*durations):
    """
    Sleep for the total number of seconds specified in the list.
    """
    time.sleep(sum(durations))

def parse_duration(s):
    try:
        return float(s)
    except ValueError:
        try:
            return float(s[:-1]) * dict(s=1, m=60, h=60*60, d=24*60*60)[s[-1]]
        except (KeyError, ValueError):
            sys.exit('invalid time interval %s' % s)

def main():
    parser = argparse.ArgumentParser(prog='sleep.py', description=__doc__)
    parser.add_argument('NUMBER', type=str, nargs='+')
    args = parser.parse_args()
    parsed_durations = (parse_duration(x) for x in args.NUMBER)
    sleep(*parsed_durations)

if __name__ == "__main__":
    main()

'''Pause for NUMBER seconds.  
SUFFIX may be 
`s' for seconds (the default),
`m' for minutes, 
`h' for hours 
`d' for days.

Unlike most implementations
that require NUMBER be an integer, here NUMBER may be an arbitrary floating
point number.  Given two or more arguments, pause for the amount of time
specified by the sum of their values.'''
