#!/usr/bin/env python
'''output the last part of files'''

# Print the last 10 lines of each FILE to standard output.
# With more than one FILE, precede each with a header giving the file name.
# With no FILE, or when FILE is -, read standard input.

import os
import sys

import argparse

parser = argparse.ArgumentParser(description=__doc__)

parser.add_argument('FILE', type=file, nargs='*', default=sys.stdin)

parser.add_argument('-c', '--bytes', metavar='N',
                    help='output the last N bytes; alternatively, use +N to'
                         'output bytes starting with the Nth of each file')
                           
parser.add_argument('-f,' '--follow', 
                    choices=('name', 'descriptor'),
                    help='output appended data as the file grows;\n'
                         '-f, --follow, and --follow=descriptor are '
                         'equivalent')
parser.add_argument('-F',
                    help='same as --follow=name --retry')
                    
parser.add_argument('-n', '--lines', metavar='N',
                    help='output the last N lines, instead of the last 10;'
                         'or use +N to output lines starting with the Nth')
                         
parser.add_argument('--max-unchanged-stats', metavar='N',
                    help='with --follow=name, reopen a FILE which has not '
                         'changed size after N (default 5) iterations '
                         'to see if it has been unlinked or renamed '
                         '(this is the usual case of rotated log files)')
                         
parser.add_argument('--pid',
                    help='with -f, terminate after process ID, PID dies')
                    
parser.add_argument('-q', '--quiet', '--silent',
                    help='never output headers giving file names')
                    
parser.add_argument('--retry',
                    help='keep trying to open a file even when it is or '
                         'becomes inaccessible; useful when following by '
                         'name, i.e., with --follow=name')
                         
parser.add_argument('-s', '--sleep-interval', metavar='S',
                    help='with -f, sleep for approximately S seconds '
                         '(default 1.0) between iterations')

parser.add_argument('-v', '--verbose',
                    help='always output headers giving file names')
                    
parser.add_argument('--version',
                    help='output version information and exit')

args = parser.parse_args()

'''If the first character of N (the number of bytes or lines) is a `+',
print beginning with the Nth item from the start of each file, otherwise,
print the last N items in the file.  N may have a multiplier suffix:
b 512, kB 1000, K 1024, MB 1000*1000, M 1024*1024,
GB 1000*1000*1000, G 1024*1024*1024, and so on for T, P, E, Z, Y.

With --follow (-f), tail defaults to following the file descriptor, which
means that even if a tail'ed file is renamed, tail will continue to track
its end.  This default behaviour is not desirable when you really want to
track the actual name of the file, not the file descriptor (e.g., log
rotation).  Use --follow=name in that case.  That causes tail to track the
named file by reopening it periodically to see if it has been removed and
recreated by some other program.

Report tail bugs to bug-coreutils@gnu.org
GNU coreutils home page: <http://www.gnu.org/software/coreutils/>
General help using GNU software: <http://www.gnu.org/gethelp/>
Report tail translation bugs to <http://translationproject.org/team/>'''
